==> chaosmesh-model-6.3.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/IOChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IOChaosFluentImpl<A extends IOChaosFluent<A>> extends BaseFluent<A> implements IOChaosFluent<A>{
  public IOChaosFluentImpl() {
  }
  public IOChaosFluentImpl(IOChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private IOChaosSpecBuilder spec;
  private IOChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public IOChaosFluent.MetadataNested<A> withNewMetadata() {
    return new IOChaosFluentImpl.MetadataNestedImpl();
  }
  public IOChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new IOChaosFluentImpl.MetadataNestedImpl(item);
  }
  public IOChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public IOChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public IOChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public IOChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public IOChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(IOChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new IOChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public IOChaosFluent.SpecNested<A> withNewSpec() {
    return new IOChaosFluentImpl.SpecNestedImpl();
  }
  public IOChaosFluent.SpecNested<A> withNewSpecLike(IOChaosSpec item) {
    return new IOChaosFluentImpl.SpecNestedImpl(item);
  }
  public IOChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public IOChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new IOChaosSpecBuilder().build());
  }
  public IOChaosFluent.SpecNested<A> editOrNewSpecLike(IOChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public IOChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public IOChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(IOChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new IOChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public IOChaosFluent.StatusNested<A> withNewStatus() {
    return new IOChaosFluentImpl.StatusNestedImpl();
  }
  public IOChaosFluent.StatusNested<A> withNewStatusLike(IOChaosStatus item) {
    return new IOChaosFluentImpl.StatusNestedImpl(item);
  }
  public IOChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public IOChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new IOChaosStatusBuilder().build());
  }
  public IOChaosFluent.StatusNested<A> editOrNewStatusLike(IOChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IOChaosFluentImpl that = (IOChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<IOChaosFluent.MetadataNested<N>> implements IOChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) IOChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends IOChaosSpecFluentImpl<IOChaosFluent.SpecNested<N>> implements IOChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(IOChaosSpec item) {
      this.builder = new IOChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new IOChaosSpecBuilder(this);
    }
    IOChaosSpecBuilder builder;
    public N and() {
      return (N) IOChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends IOChaosStatusFluentImpl<IOChaosFluent.StatusNested<N>> implements IOChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(IOChaosStatus item) {
      this.builder = new IOChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new IOChaosStatusBuilder(this);
    }
    IOChaosStatusBuilder builder;
    public N and() {
      return (N) IOChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/IOChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IOChaosFluentImpl<A extends IOChaosFluent<A>> extends BaseFluent<A> implements IOChaosFluent<A>{
  public IOChaosFluentImpl() {
  }
  public IOChaosFluentImpl(IOChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private IOChaosSpecBuilder spec;
  private IOChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public IOChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new IOChaosFluentImpl.MetadataNestedImpl();
  }
  public IOChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new IOChaosFluentImpl.MetadataNestedImpl(item);
  }
  public IOChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public IOChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public IOChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public IOChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public IOChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(IOChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new IOChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public IOChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new IOChaosFluentImpl.SpecNestedImpl();
  }
  public IOChaosFluentImpl.SpecNested<A> withNewSpecLike(IOChaosSpec item) {
    return new IOChaosFluentImpl.SpecNestedImpl(item);
  }
  public IOChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public IOChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new IOChaosSpecBuilder().build());
  }
  public IOChaosFluentImpl.SpecNested<A> editOrNewSpecLike(IOChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public IOChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public IOChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(IOChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new IOChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public IOChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new IOChaosFluentImpl.StatusNestedImpl();
  }
  public IOChaosFluentImpl.StatusNested<A> withNewStatusLike(IOChaosStatus item) {
    return new IOChaosFluentImpl.StatusNestedImpl(item);
  }
  public IOChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public IOChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new IOChaosStatusBuilder().build());
  }
  public IOChaosFluentImpl.StatusNested<A> editOrNewStatusLike(IOChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IOChaosFluentImpl that = (IOChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<IOChaosFluentImpl.MetadataNested<N>> implements IOChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) IOChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends IOChaosSpecFluentImpl<IOChaosFluentImpl.SpecNested<N>> implements IOChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(IOChaosSpec item) {
      this.builder = new IOChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new IOChaosSpecBuilder(this);
    }
    IOChaosSpecBuilder builder;
    public N and() {
      return (N) IOChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends IOChaosStatusFluentImpl<IOChaosFluentImpl.StatusNested<N>> implements IOChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(IOChaosStatus item) {
      this.builder = new IOChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new IOChaosStatusBuilder(this);
    }
    IOChaosStatusBuilder builder;
    public N and() {
      return (N) IOChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
